# pylint:disable=no-name-in-module,attribute-defined-outside-init
import os
import sys
import tempfile

from PyQt5.QtCore import QIODevice
from PyQt5.QtWidgets import QMessageBox, QApplication
from PyQt5.QtNetwork import QLocalServer, QLocalSocket


# noinspection PyPep8Naming,PyAttributeOutsideInit,PyTypeChecker
class QSingleApplication(QApplication):
    socket_name = 'qtsingleapp_vdi_client.sock'
    lock_name = 'qtsingleapp_vdi_client.lock'

    def start(self, main_window, single=False):
        if single:
            self._single_start(main_window)
        else:
            main_window.show()
        self.exec_()

    def _single_start(self, main_window):
        self.setQuitOnLastWindowClosed(False)
        self.mainWindow = main_window
        # Socket
        self.m_socket = QLocalSocket()
        self.m_socket.connected.connect(self.restoreExistingApp)
        self.m_socket.error.connect(self.startApplication)
        self.m_socket.connectToServer(self.socket_name, QIODevice.WriteOnly)

    def restoreExistingApp(self):
        self.m_socket.write('show')
        self.m_socket.bytesWritten.connect(self.quit)

    def startApplication(self):
        self.m_server = QLocalServer()

        if sys.platform != "win32":
            self._cleanup_socket()

        if self.m_server.listen(self.socket_name):
            self.m_server.newConnection.connect(self.on_new_connection)
            self.mainWindow.show()
        else:
            QMessageBox.critical(None, "Error", "Error listening the socket.")
            self.exit(1)

    def _cleanup_socket(self):
        import fcntl
        # workaround to cleanup socket if app is not running
        temp_dir = tempfile.gettempdir()
        lock_path = os.path.join(temp_dir, self.lock_name)
        socket_path = os.path.join(temp_dir, self.socket_name)
        lock = os.open(lock_path, os.O_CREAT)
        try:
            fcntl.flock(lock, fcntl.LOCK_EX | fcntl.LOCK_NB)
        except (OSError, IOError):
            pass
        else:
            if os.path.exists(socket_path):
                os.remove(socket_path)

    def on_new_connection(self):
        self.new_socket = self.m_server.nextPendingConnection()
        self.new_socket.readyRead.connect(self.readSocket)

    def readSocket(self):
        f = self.new_socket.readLine()
        if f == 'show':
            self.mainWindow.restore_from_tray()
