# coding: utf-8
# pylint: disable=c-extension-no-member,no-name-in-module,import-error

from PyQt5 import QtGui
from PyQt5.QtWidgets import QDialog, QLineEdit

from tionix_vdi_client.gui.ui_pin import Ui_PinWindow


class PinWindow(QDialog):

    pin = None
    eye_opened = ":/icons/eye_opened.png"
    eye_crossed = ":/icons/eye_crossed.png"

    def __init__(self, parent=None, attempts=None, min_len=None, max_len=None):
        super(PinWindow, self).__init__(parent)
        self.ui = Ui_PinWindow()
        self.ui.setupUi(self)

        self.min_len = min_len
        self.max_len = max_len
        if self.min_len:
            self.ui.button_ok.setEnabled(False)

        if attempts is None or attempts < 4:
            self.ui.label_attempts_count.setStyleSheet(
                'QLabel {color: red; font-weight: bold}')
        attempts = attempts or '?'
        self.ui.label_attempts_count.setText(str(attempts))

        self.ui.input_pin.textChanged.connect(self.on_pin_changed)
        self.ui.input_pin.returnPressed.connect(self.on_ok_clicked)

        self.input_pin_state = self.ui.input_pin.addAction(
            QtGui.QIcon(self.eye_opened),
            QLineEdit.ActionPosition.TrailingPosition)
        self.input_pin_state.triggered.connect(
            self.change_state)

        self.ui.button_ok.clicked.connect(self.on_ok_clicked)
        self.ui.button_cancel.clicked.connect(self.reject)

    def change_state(self):
        if self.ui.input_pin.echoMode() is QLineEdit.Password:
            self.input_pin_state.setIcon(
                QtGui.QIcon(self.eye_crossed))
            self.ui.input_pin.setEchoMode(QLineEdit.Normal)
        else:
            self.input_pin_state.setIcon(
                QtGui.QIcon(self.eye_opened))
            self.ui.input_pin.setEchoMode(QLineEdit.Password)

    def on_ok_clicked(self):
        if self.ui.button_ok.isEnabled():
            self.pin = self.ui.input_pin.text()
            self.close()

    def on_pin_changed(self):
        pin = self.ui.input_pin.text()
        enabled = True
        if self.min_len is not None and len(pin) < self.min_len:
            enabled = False
        if self.max_len is not None and len(pin) > self.max_len:
            self.ui.input_pin.setText(pin[:self.max_len])
        self.ui.button_ok.setEnabled(enabled)

    @staticmethod
    def get_pin(parent=None, attempts=None, min_len=None, max_len=None):
        window = PinWindow(parent=parent, attempts=attempts,
                           min_len=min_len, max_len=max_len)
        window.exec_()
        return window.pin
