# coding: utf-8
import logging
import re
from collections import deque


class RedactingFilter(logging.Filter):

    def __init__(self, exprs):
        super(RedactingFilter, self).__init__()
        self._exprs = exprs

    def filter(self, record):
        record.msg = self.redact(record.msg)
        if isinstance(record.args, dict):
            record.args = {key: self.redact(value) for key, value in
                           list(record.args.items())}
        else:
            record.args = tuple(self.redact(arg) for arg in record.args)
        return True

    def redact(self, msg):
        msg = msg if isinstance(msg, str) else str(msg)

        for expr in self._exprs:
            if isinstance(expr, tuple):
                expr, replace_str = expr
            else:
                replace_str = None
            pattern = re.search(expr, msg)
            if pattern:
                msg = msg.replace(pattern.group(), replace_str or "")
        return msg


_log_buffer = []


class BufferingStreamHandler(logging.StreamHandler):

    def __init__(self, stream=None, buffer_size=10):
        super(BufferingStreamHandler, self).__init__(stream)
        global _log_buffer
        _log_buffer = deque(maxlen=buffer_size)
        self.buffer = _log_buffer

    def emit(self, record):
        self.buffer.append(self.format(record))
        super(BufferingStreamHandler, self).emit(record)


def get_log_msg():
    """Return last saved log messages."""
    global _log_buffer
    return "\n".join(reversed(_log_buffer))
