# coding: utf-8

import unittest
from contextlib import contextmanager

from tionix_vdi_client import exceptions, client
from tionix_vdi_client.i18n import ugettext as _
from tionix_vdi_client.settings import CONF


@contextmanager
def patch_dict(dictionary, **kwargs):
    """Patch dict with kwargs and restore original values upon exit."""
    orig_dict = dictionary.copy()
    dictionary.update(**kwargs)
    try:
        yield
    finally:
        dictionary.clear()
        dictionary.update(**orig_dict)


class VDIConnectionTest(unittest.TestCase):

    conn_params = {
        'user': 'self-diagnostic-user',
        'password': 'non-existing-password',
        'domain_name': 'non-existing-domain',
    }

    def test_check_vdi_server_connection(self):
        """Checks that VDIclient can connect to VDIserver.

        :lang:ru Проверяет что VDIclient может подключиться к VDIserver.
        """
        try:
            vdi_client = client.VdiClient(**self.conn_params)
        except Exception as err:
            self.fail(str(err))
        try:
            # noinspection PyUnresolvedReferences
            with patch_dict(CONF, timeout=1, retries=1):
                vdi_client.request_vm()
        except exceptions.VDIServerResponseError as err:
            if err.code != exceptions.ErrorCodes.AUTH_ERROR:
                self.fail(str(err))
        except Exception as err:
            self.fail(_("Unexpected server response. "
                        "{0}").format(str(err)))
