# coding: utf-8

import locale
import unittest

from tionix_vdi_client.i18n import switch_language
from tionix_vdi_client.settings import CONF

try:
    from tionix_client.functional import DetailedTestRunner
except ImportError:
    DetailedTestRunner = None

language, _encoding = locale.getdefaultlocale()
ENV_LANGUAGE_CODE = language or 'en_US.UTF-8'


def run_func_tests(runner=DetailedTestRunner, debug=False):
    if not runner:
        return None

    if runner is DetailedTestRunner:
        switch_language(ENV_LANGUAGE_CODE)

    # dynamic tests loading is not working in windows build,
    # so load tests explicitly
    from tionix_vdi_client.tests.functional. \
        func_test_vdi_client_server_connection import VDIConnectionTest
    from tionix_vdi_client.tests.functional. \
        func_test_vdi_client_check_config_files import ConfigFilesTest
    from tionix_vdi_client.tests.functional. \
        func_test_vdi_client_check_localization import LocalizationFilesTests

    config_suite = unittest.TestLoader().loadTestsFromTestCase(
        ConfigFilesTest)
    localization_suite = unittest.TestLoader().loadTestsFromTestCase(
        LocalizationFilesTests)
    vdi_suite = unittest.TestLoader().loadTestsFromTestCase(
        VDIConnectionTest)
    test_suite = unittest.TestSuite(
        [config_suite, localization_suite, vdi_suite])

    test_result = runner(debug=debug).run(test_suite)

    if runner is DetailedTestRunner:
        test_result = test_result.to_dict()
        test_result['variables'] = CONF

    return test_result


if __name__ == '__main__':
    run_func_tests()
