# coding: utf-8

# noinspection PyPep8Naming
import configparser as configparser

from mock import Mock, patch

from tionix_client.tests.test_diagnostic.base import BaseTestDiagnostic

from tionix_vdi_client.settings import ConfigSettings, SessionSettings
from tionix_vdi_client.tests.functional import (
    func_test_vdi_client_check_config_files)

fake_client_conf_path = '/user/.tionix-vdi-client/client.conf'
fake_client_session_path = '/user/.tionix-vdi-client/tnx_client_session'


@patch('tionix_vdi_client.tests.functional.'
       'func_test_vdi_client_check_config_files.ConfigSettings.'
       '_default_config_name', fake_client_conf_path)
@patch('tionix_vdi_client.tests.functional.'
       'func_test_vdi_client_check_config_files.SessionSettings.'
       '_session_file_name', fake_client_session_path)
class ConfigFileTestCase(BaseTestDiagnostic):
    case = func_test_vdi_client_check_config_files.ConfigFilesTest

    @patch("tionix_vdi_client.tests.functional."
           "func_test_vdi_client_check_config_files.configparser.ConfigParser")
    def test_config_file_read_save__read_failed(self, conf_parser_mock):
        name = 'test_config_file_read_save'
        fake_config = Mock()
        fake_config.read = Mock(side_effect=configparser.ParsingError("file"))
        conf_parser_mock.return_value = fake_config
        self.assert_test_fails(name)

    @patch("tionix_vdi_client.tests.functional."
           "func_test_vdi_client_check_config_files."
           "ConfigSettings.save", new=Mock())
    def test_config_file_read_save__doesnt_save(self):
        name = 'test_config_file_read_save'
        self.assert_test_fails(name)

    @patch("tionix_vdi_client.tests.functional."
           "func_test_vdi_client_check_config_files.configparser.ConfigParser")
    def test_session_file_read_save__read_failed(self, conf_parser_mock):
        name = 'test_session_file_read_save'
        fake_config = Mock()
        fake_config.read = Mock(side_effect=configparser.ParsingError("file"))
        conf_parser_mock.return_value = fake_config
        self.assert_test_fails(name)

    @patch("tionix_vdi_client.tests.functional."
           "func_test_vdi_client_check_config_files."
           "SessionSettings.read", autospec=True)
    def test_session_file_read_save__doesnt_read(self, read_session_mock):
        def fake_read(slf):
            slf.user = 'fake'
        name = 'test_session_file_read_save'
        read_session_mock.side_effect = fake_read
        self.assert_test_fails(name)

    @patch("tionix_vdi_client.tests.functional."
           "func_test_vdi_client_check_config_files."
           "ConfigFilesTest.find_empty_parameters",
           new=Mock(return_value=ConfigSettings.required_attributes))
    def test_config_file_has_required_values__keys_missing(self):
        name = 'test_config_file_has_required_values'
        self.assert_test_fails(name)

    @patch("tionix_vdi_client.tests.functional."
           "func_test_vdi_client_check_config_files."
           "ConfigFilesTest.find_empty_parameters",
           new=Mock(return_value=SessionSettings.required_attributes))
    def test_session_file_has_required_values__keys_missing(self):
        name = 'test_session_file_has_required_values'
        self.assert_test_fails(name)
