# coding: utf-8
import json
import os
import tempfile

import requests

from tionix_vdi_client.settings import ConfigSettings


class TempConfig(ConfigSettings):
    """Temporary config file."""

    def __init__(self):
        super(TempConfig, self).__init__()
        self.default[ConfigSettings.TIMEOUT] = 0

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.delete_config()

    def __setattr__(self, item, value):
        try:
            super(TempConfig, self).__setattr__(item, value)
        except AttributeError:
            object.__setattr__(self, item, value)

    @property
    def _default_config_name(self):
        return self._conf_file

    def delete_config(self):
        os.remove(self._default_config_name)

    def create_configuration_file(self):
        with open(self._sample_config_name, 'r') as fd:
            example = fd.readlines()
        _fd, self._conf_file = tempfile.mkstemp(suffix='.cfg')
        with open(self._conf_file, 'w') as fd:
            fd.writelines(example)


class Response(requests.Response):
    """Fake response."""

    def __init__(self, **kwargs):
        super(Response, self).__init__()
        self.url = kwargs.pop('url', 'localhost.test')
        self.status_code = kwargs.pop('status_code', 200)
        if 'json' in kwargs:
            self._content = json.dumps(kwargs['json'])
        else:
            self._content = kwargs.pop('content', '')
