# coding: utf-8

import unittest

from tionix_vdi_client import helpers


class TestHelpers(unittest.TestCase):
    def test_get_vdi_api_url_validate_urls(self):
        """Checks valid urls formatting"""
        test_urls = (
            ("test.stand.loc", "http://test.stand.loc:9365"),
            ("test.stand.loc:80", "http://test.stand.loc:80"),
            ("test.stand.loc:80/vdi/api", "http://test.stand.loc:80"),
            ("http://test.stand.loc", "http://test.stand.loc:9365"),
            ("test.stand.loc:9365", "http://test.stand.loc:9365"),
            ("http://test.stand.loc/vdi/api",
             "http://test.stand.loc:9365"),
        )
        for given_url, expected_output in test_urls:
            result_url = helpers.get_vdi_api_url(given_url)
            self.assertEqual(result_url, expected_output)

    def test_get_vdi_api_url_invalid_urls(self):
        """Test with invalid call arguments"""
        invalid_urls = (4, 3.14, True, None)
        for invalid_url in invalid_urls:
            self.assertRaises(Exception, helpers.get_vdi_api_url, invalid_url)


class TestPasswords(unittest.TestCase):
    def test_generate(self):
        password = helpers.PasswordGenerator.generate()
        self.assertEqual(helpers.PasswordGenerator.PASSWORD_MIN,
                         len(password))
        self.assertTrue(helpers.PasswordGenerator.check(password))

        password = helpers.PasswordGenerator.generate(10)
        self.assertEqual(len(password), 10)
        self.assertTrue(helpers.PasswordGenerator.check(password))

    def test_check(self):
        password = 'password'  # invalid
        self.assertFalse(helpers.PasswordGenerator.check(password))
        password = 'passwor'  # too short
        self.assertFalse(helpers.PasswordGenerator.check(password))
        password = 'pa$$w0rd'  # no upper case
        self.assertFalse(helpers.PasswordGenerator.check(password))
        password = 'pa$$worD'  # no digits
        self.assertFalse(helpers.PasswordGenerator.check(password))
        password = 'passw0rD'  # no special symbols
        self.assertFalse(helpers.PasswordGenerator.check(password))
        password = 'pa$$w0rD'  # valid
        self.assertTrue(helpers.PasswordGenerator.check(password))
        password = 'pA$$w0rD'  # also valid
        self.assertTrue(helpers.PasswordGenerator.check(password))
