# coding: utf-8
import os
import platform
import tempfile
import unittest
import mock
from pbr import packaging

from tionix_vdi_client.version_writter import (
    get_win_os_bitness, write_version_to_file, VERSION_FILE_CONTENT)
from tionix_vdi_client import version_writter


class TestWriters(unittest.TestCase):
    def setUp(self):
        super(TestWriters, self).setUp()
        self.test_version = 'test_version'
        self.file_with_version = os.path.join(
            tempfile.gettempdir(), 'vdi_client_version_file.txt')

        self.ORIGIN_FILE_WITH_VERSION = version_writter.FILE_WITH_VERSION
        version_writter.FILE_WITH_VERSION = self.file_with_version

    def tearDown(self):
        super(TestWriters, self).tearDown()
        version_writter.FILE_WITH_VERSION = self.ORIGIN_FILE_WITH_VERSION

    def test_get_win_os_bitness(self):
        platform.architecture = mock.Mock(return_value=('64', 'windows'))
        self.assertEqual(get_win_os_bitness(), 'x64')
        platform.architecture = mock.Mock(return_value=('32', 'windows'))
        self.assertEqual(get_win_os_bitness(), 'x32')

    def test_write_version_to_file(self):
        platform.architecture = mock.Mock(return_value=('64', 'windows'))
        packaging.get_version = mock.Mock(return_value=self.test_version)
        version, os_bitness = write_version_to_file()
        self.assertEqual(self.test_version, version)
        self.assertEqual('x64', os_bitness)

        with open(self.file_with_version, 'r') as opened_file:
            val = opened_file.read()
        val1 = VERSION_FILE_CONTENT.format(version=version, bitness=os_bitness)
        self.assertEqual(val, val1)
