# coding: utf-8

import platform


VERSION_FILE_CONTENT = """
# This file is generated during building tionix_vdi_client distribution

__version__ = u"{version}"
__os_bitness__ = u"{bitness}"
"""

FILE_WITH_VERSION = 'tionix_vdi_client/version.py'


def get_win_os_bitness():
    """Get Windows bitness. For Linux returns empty string."""
    bitness = ''
    os_bitness, os_name = platform.architecture()
    if 'windows' in os_name.lower():
        if '64' in os_bitness:
            bitness = 'x64'
        else:
            bitness = 'x32'
    return bitness


def write_version_to_file():
    """Getting version of TIONIX.VDIclient using pbr along with
    Windows bitness and save it to file. File name for storing version
    is in FILE_WITH_VERSION constant

    When pbr has imported, distutils.dist.Distribution class was patching
    by setuptools.dist.Distribution class. Because of this after calling
    cx_Freeze.setup() TypeError was raised:

    TypeError: unbound method __init__() must be called with Distribution
    instance as first argument (got Distribution instance instead)

    The code below fix it.
    """
    from distutils import dist
    before_patch_class = dist.Distribution
    from pbr import packaging
    dist.Distribution = before_patch_class

    version = packaging.get_version('tionix_vdi_client')
    os_bitness = get_win_os_bitness()
    with open(FILE_WITH_VERSION, "w") as opened_file:
        opened_file.write(VERSION_FILE_CONTENT.format(
            version=version,
            bitness=os_bitness
        ))

    return version, os_bitness
