# coding: utf-8
# pylint: disable=import-error
import itertools


# noinspection PyUnresolvedReferences
def supported_device_classes():
    import winreg as winreg
    ids = []
    try:
        reg_key = winreg.OpenKey(
            winreg.HKEY_LOCAL_MACHINE,
            "SOFTWARE\\Policies\\Microsoft\\Windows NT\\"
            "Terminal Services\\Client", 0, winreg.KEY_READ)
        val, _type = winreg.QueryValueEx(
            reg_key, "fUsbRedirectionEnableMode")
    # pylint: disable=undefined-variable
    except WindowsError:
        return ids

    if val != 2:
        return ids

    reg_key = winreg.OpenKey(
        winreg.HKEY_LOCAL_MACHINE,
        "SOFTWARE\\Policies\\Microsoft\\Windows NT"
        "\\Terminal Services\\Client\\UsbSelectDeviceByInterfaces",
        0, winreg.KEY_READ)
    try:
        for i in itertools.count():
            _name, value, _type = winreg.EnumValue(reg_key, i)
            ids.append(value)
    # pylint: disable=undefined-variable
    except WindowsError:
        pass
    return ids


# noinspection PyUnresolvedReferences
def get_pnp_devices():
    import win32com.client
    wmi_service = win32com.client.Dispatch("WbemScripting.SWbemLocator")
    swbem_ervices = wmi_service.ConnectServer(".", "root\\cimv2")
    return swbem_ervices.ExecQuery("SELECT * FROM Win32_PnPEntity")


# pylint: disable=inconsistent-return-statements
def find_parent_device_id(device_id, devices):
    # &MI_ means device is composite usb device
    if '&MI_' not in device_id:
        return None
    device_prefix = device_id.split('&MI_')[0]
    for device in devices:
        if device.DeviceID == device_id:
            continue
        if (device.DeviceID.startswith(device_prefix) and
                '&MI_' not in device.DeviceID):
            return device.DeviceID


def find_device_children_ids(device_id, devices):
    children = []
    prefix = '\\'.join(device_id.split('\\')[:2]) + '&MI_'
    for device in devices:
        if device.DeviceID.startswith(prefix):
            children.append(device.DeviceID)
    return children
