# coding: utf-8
"""
Wrappers for Windows API functions
"""

import ctypes
from ctypes import (
    Structure, POINTER, c_char, c_ulong, c_voidp, sizeof, byref,
    cast, create_string_buffer)


CRYPTPROTECT_UI_FORBIDDEN = 0x01
CRYPTPROTECT_LOCAL_MACHINE = 0x04


class DataBlob(Structure):
    """Structure containing an array of bytes

    cbData: A DWORD variable that contains the count, in bytes, of data.
    pbData: A pointer to the data buffer.
    """
    _fields_ = [
        ("cbData", c_ulong),
        ("pbData", POINTER(c_char))
    ]

    def get_data(self):
        """Get data from pointer and convert to str"""
        bytes_count = int(self.cbData)
        data = ''
        void_p = cast(self.pbData, c_voidp).value
        for counter in range(bytes_count):
            p = cast(void_p + sizeof(c_char) * counter, POINTER(c_char))
            data += p.contents.value
        return data


# pylint: disable=inconsistent-return-statements
def crypt_protect_data(plain_text):
    """Wrapper for CryptProtectData function"""
    plain_text = plain_text.encode('utf-16-le')
    buffer_in = create_string_buffer(plain_text, len(plain_text))
    blob_in = DataBlob(len(plain_text), buffer_in)
    blob_out = DataBlob()
    desc = 'psw'
    flags = CRYPTPROTECT_UI_FORBIDDEN | CRYPTPROTECT_LOCAL_MACHINE
    # The CryptProtectData function performs encryption on the data
    # in a DATA_BLOB structure.
    # BOOL WINAPI CryptProtectData(
    #   _In_       DATA_BLOB                 *pDataIn,
    #   _In_opt_   LPCWSTR                   szDataDescr,
    #   _In_opt_   DATA_BLOB                 *pOptionalEntropy,
    #   _Reserved_ PVOID                     pvReserved,
    #   _In_opt_   CRYPTPROTECT_PROMPTSTRUCT *pPromptStruct,
    #   _In_       DWORD                     dwFlags,
    #   _Out_      DATA_BLOB                 *pDataOut
    # );
    if ctypes.windll.crypt32.CryptProtectData(
            byref(blob_in), desc, None, None, None, flags, byref(blob_out)):
        return blob_out.get_data()


def message_box(message, title):
    """Wrapper for MessageBoxW function"""
    ctypes.windll.user32.MessageBoxW(None, message, title, 0)
